@@ -281,7 +281,7 @@ class SemanticModel:
             sem_types.add(SemanticType(u.abs_uri, e.abs_uri, u.rel_uri, e.rel_uri))
         return sem_types
 
-    def to_json(self):
+    def to_dict(self):
         return {
             "version": 1,
             "nodes": [asdict(u) for u in self.iter_nodes()],
@@ -290,7 +290,7 @@ class SemanticModel:
 
     def to_json_file(self, outfile: Union[str, Path]):
         with open(outfile, "wb") as f:
-            f.write(orjson.dumps(self.to_json(), option=orjson.OPT_INDENT_2))
+            f.write(orjson.dumps(self.to_dict(), option=orjson.OPT_INDENT_2))
 
     @staticmethod
     def from_json(record: dict):
